Miscellaneous
=============

Probability
-----------

.. python-apigen-group:: probability

Independent random variables
----------------------------

.. python-apigen-group:: independent-rvs

IID random variables
--------------------

.. python-apigen-group:: iid-rvs

Data manipulation
-----------------

.. python-apigen-group:: data
